@@ -1,5 +1,3 @@
-# $Id: decayingDimer.R 73 2007-08-18 23:39:50Z pineda $
-
 #===============================================================================
 # Decaying-Dimerization Reaction Set (Gillespie, 2001)
 #===============================================================================
@@ -11,12 +9,7 @@
 #      S2 --c3--> S1 + S1
 #      S2 --c4--> S3
 
-# Rate parameters
-assign("c1", c1 <- 1.0,   env=.GlobalEnv)
-assign("c2", c2 <- 0.002, env=.GlobalEnv)
-assign("c3", c3 <- 0.5,   env=.GlobalEnv)
-assign("c4", c4 <- 0.04,  env=.GlobalEnv)
-
+parms <- c(c1=1.0, c2=0.002, c3=0.5, c4=0.04)
 x0 <- c(s1=10000, s2=0, s3=0)      # Initial state vector
 nu <- matrix(c(-1, -2, +2,  0,     # State-change matrix
                 0, +1, -1, -1,
@@ -28,21 +21,20 @@ tf <- 30                           # Final time
 simName <- "Decaying-Dimerizing Reaction Set"
 
 # Run simulations 
-
 # Direct method
-out <- ssa(x0,a,nu,tf,method="D",simName,
+out <- ssa(x0,a,nu,parms,tf,method="D",simName,
            consoleInterval=0.1,censusInterval=0.1,
            verbose=TRUE,maxWallTime=10) 
 ssa.plot(out)
 
 # Explict tau-leap method
-out <- ssa(x0,a,nu,tf,method="ETL",simName,tau=0.003) 
+out <- ssa(x0,a,nu,parms,tf,method="ETL",simName,tau=0.003) 
 ssa.plot(out) 
 
 # Binomial tau-leap method
-out <- ssa(x0,a,nu,tf,method="BTL",simName) 
+out <- ssa(x0,a,nu,parms,tf,method="BTL",simName) 
 ssa.plot(out) 
 
 # Binomial tau-leap method
-out <- ssa(x0,a,nu,tf,method="OTL",simName) 
+out <- ssa(x0,a,nu,parms,tf,method="OTL",simName) 
 ssa.plot(out) 
